==> bocp-transfer-domain-1.8.2-sources.jar: com/xforceplus/ultraman/transfer/domain/entity/MetadataEntity.java <==
package com.xforceplus.ultraman.transfer.domain.entity;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * CopyRight: 上海云砺信息科技有限公司
 * User: youyifan
 * DateTime: 2023/4/21 10:30
 * Description:
 * History:
 */

public class MetadataEntity implements Serializable {
    private static final long serialVersionUID = 1L;

    Long id;
    Long appId;
    Boolean isDeploy = false;
    Long metadataId;
    String metadataType;
    String content;
    String version;
    Integer versionNumber;
    String tenantCode;
    String profile;

    LocalDateTime createTime;

    LocalDateTime updateTime;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Boolean getDeploy() {
        return isDeploy;
    }

    public void setDeploy(Boolean deploy) {
        isDeploy = deploy;
    }

    public Long getMetadataId() {
        return metadataId;
    }

    public void setMetadataId(Long metadataId) {
        this.metadataId = metadataId;
    }

    public String getMetadataType() {
        return metadataType;
    }

    public void setMetadataType(String metadataType) {
        this.metadataType = metadataType;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public Integer getVersionNumber() {
        return versionNumber;
    }

    public void setVersionNumber(Integer versionNumber) {
        this.versionNumber = versionNumber;
    }

    public String getTenantCode() {
        return tenantCode;
    }

    public void setTenantCode(String tenantCode) {
        this.tenantCode = tenantCode;
    }

    public String getProfile() {
        return profile;
    }

    public void setProfile(String profile) {
        this.profile = profile;
    }

    public LocalDateTime getCreateTime() {
        return createTime;
    }

    public void setCreateTime(LocalDateTime createTime) {
        this.createTime = createTime;
    }

    public LocalDateTime getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(LocalDateTime updateTime) {
        this.updateTime = updateTime;
    }
}

==> bocp-transfer-domain-1.10.13-sources.jar: com/xforceplus/ultraman/transfer/domain/entity/MetadataEntity.java <==
package com.xforceplus.ultraman.transfer.domain.entity;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * CopyRight: 上海云砺信息科技有限公司
 * User: youyifan
 * DateTime: 2023/4/21 10:30
 * Description:
 * History:
 */

public class MetadataEntity implements Serializable {
    private static final long serialVersionUID = 1L;

    Long id;
    Long appId;
    Boolean isDeploy = false;
    Long metadataId;
    String metadataType;
    String content;
    String version;
    Integer versionNumber;
    String tenantCode;
    String profile;
    String teamCode;
    LocalDateTime createTime;
    LocalDateTime updateTime;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Boolean getDeploy() {
        return isDeploy;
    }

    public void setDeploy(Boolean deploy) {
        isDeploy = deploy;
    }

    public Long getMetadataId() {
        return metadataId;
    }

    public void setMetadataId(Long metadataId) {
        this.metadataId = metadataId;
    }

    public String getMetadataType() {
        return metadataType;
    }

    public void setMetadataType(String metadataType) {
        this.metadataType = metadataType;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public Integer getVersionNumber() {
        return versionNumber;
    }

    public void setVersionNumber(Integer versionNumber) {
        this.versionNumber = versionNumber;
    }

    public String getTenantCode() {
        return tenantCode;
    }

    public void setTenantCode(String tenantCode) {
        this.tenantCode = tenantCode;
    }

    public String getProfile() {
        return profile;
    }

    public void setProfile(String profile) {
        this.profile = profile;
    }

    public LocalDateTime getCreateTime() {
        return createTime;
    }

    public void setCreateTime(LocalDateTime createTime) {
        this.createTime = createTime;
    }

    public LocalDateTime getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(LocalDateTime updateTime) {
        this.updateTime = updateTime;
    }

    public String getTeamCode() {
        return teamCode;
    }

    public void setTeamCode(String teamCode) {
        this.teamCode = teamCode;
    }
}
